from prettyqt.qt import QtCore


class Runnable(QtCore.QRunnable):
    pass
